#
# spec file for package cinnamon-session
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cinnamon-session
Version:        3.4.1
Release:        2.2
Summary:        The session manager for the Cinnamon Desktop
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/GUI/Other
Url:            https://github.com/linuxmint/cinnamon-session
Source:         https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-logind.gschema.override
# PATCH-FIX-OPENSUSE cinnamon-session-fix-qt-themes.patch boo#1002900 sor.alexei@meowr.ru -- Use Gtk2 Platform Theme on Qt 5.7+ and no gnome theme on 5.6.
Patch0:         cinnamon-session-fix-qt-themes.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  docutils
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  tcpd-devel
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  xtrans
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pangox)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xtst)
Requires:       cinnamon
Requires:       cinnamon-settings-daemon
Requires:       dbus-1-x11
Requires:       upower >= 0.9.0
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if 0%{?suse_version} > 1320
# Make native styling in Qt5 happen.
Requires:       libqt5-qtstyleplugins-platformtheme-gtk2
%endif

%description
This packages contains the session manager for the Cinnamon Desktop.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
%if 0%{?suse_version} > 1320
  --enable-qt57-theme-support
%else
  --disable-qt57-theme-support
%endif
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}-3.0 %{?no_lang_C}

# We should own this directory.
mkdir -p %{buildroot}%{_datadir}/%{name}/sessions/

# Fix documentation location.
mkdir -p %{buildroot}%{_docdir}/
mv -f %{buildroot}%{_datadir}/doc/%{name}/ \
  %{buildroot}%{_docdir}/%{name}/

# Use systemd-logind for suspend by default.
install -Dpm 0644 %{SOURCE1} \
  %{buildroot}%{_datadir}/glib-2.0/schemas/org.cinnamon.desktop.session.gschema.override

%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README README.md
%dir %{_docdir}/%{name}/dbus/
%doc %{_docdir}/%{name}/dbus/%{name}.html
%{_bindir}/%{name}
%{_bindir}/%{name}-quit
%{_libexecdir}/%{name}-check-accelerated*
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/org.cinnamon.*
%{_datadir}/icons/hicolor/*/apps/%{name}-properties.*
%{_mandir}/man?/%{name}*.?%{?ext_man}

%files lang -f %{name}-3.0.lang
%defattr(-,root,root)

%changelog
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 3.4.1:
  * autostart-blacklist: Add the new gnome settings daemon prefix.
  * csm-manager.c: Listen to the power schema "lock-on-suspend"
    setting instead of the normal screensaver setting of
    "lock when the screensaver starts".
* Tue Jun 13 2017 fvogt@suse.com
- Fix installation on Leap 42.3, it has Qt 5.6 and does not provide
  libqt5-qtstyleplugins-platformtheme-gtk2
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * Check stricter for presence of xtrans (with option to disable).
  * Remove aclocal from autogen.sh.
  * Fix redundant redeclarations.
  * manager: Don't wait for all clients to exit before exiting.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Remove an old dialog icon code.
  * gsettings: Stop using g_settings_list_schemas().
  * Use a qt5ct platform theme on Qt 5.7+, qgnomeplatform on 5.6
    and earlier.
  * Use a build time option instead of pkgcheck.
  * Incorporate feedback.
  * Replace the deprecated gtk_icon_info_free() with g_object_unref().
  * main: Fix a heap overflow in dbus-launch wrapping.
  * Add cinnamon-session.pot and makepot.
- Rename and rebase cinnamon-session-qt-5.7-styleoverride.patch to
  cinnamon-session-fix-qt-themes.patch.
* Fri Oct 21 2016 sor.alexei@meowr.ru
- Require libqt5-qtstyleplugins-platformtheme-gtk2 to make sure the
  user actually gets native styling on Qt5 (boo#1002900).
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Add cinnamon-session-qt-5.7-styleoverride.patch: On Qt 5.7+ use
  Gtk2 Platform Theme and don't set QT_STYLE_OVERRIDE to "gtk"
  (boo#1002900).
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * Add support PreDisplayServer phase to fix gnome-keyring ssh
    issue.
  * Add new phase: CSM_MANAGER_PHASE_EARLY_INITIALIZATION, it's
    needed for PRE_DISPLAY_SERVER phase to run.
  * main.c: Add support for disabling gtk overlay scrollbars.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * main.c: Remove CLUTTER_BACKEND=x11 (moved to cinnamon main.c).
  * mdm: Fix logic error.
  * Fix a typo in a warning message.
  * Add a provides for x-session-manager.
  * Support new libsystemd (which replaces libsystemd-login).
  * Fix GTK+ regression in csm-inhibit-dialog.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 2.8.3:
  * mdm: Fix logic error.
  * Fix a typo in a warning message.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 2.8.2:
  * Autostart: Blacklist xfce4-power-manager.
- Change licence to GPL-2.0+ and LGPL-2.1+.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 2.8.1:
  * csm-logout-dialog.c: Add "automatically" to the msgids of the
  countdown label. This uses the already-translated msgid.
* Tue Oct 20 2015 sor.alexei@meowr.ru
- Update to 2.8.0:
  * Add a gsettings key to enable debug.
  * Reject new XSMP clients earlier in the shutdown path.
  * xsmp: Re-accept clients if session shutdown is cancelled.
  * Avoid to keep zombie clients in the case when a IceError is
    thrown between accept_ice_connection() and
    accept_xsmp_connection().
  * Only wait 1 second max on logout/shutdown.
  * Log time delta in debug mode. Also, don't log dbus calls (they
    don't show much info and they're very numerous).
  * Make Qt5 apps follow the Gtk style.
  * Make the session blacklist entirely configurable.
  * Replace indicator- with indicator-session in session blacklist.
  * Renamed blacklist -> autostart-blacklist.
- Fix dependencies.
- Generate icon cache.
* Tue Aug 11 2015 i@marguerite.su
- use systemd-logind for suspend and etc. by default
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.3
  * main.c: prevent overlay-scrollbar from loading
  * csm-manager: add a whitelist to override autostart hardcoded list
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.2
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.3
* Mon Nov 10 2014 i@marguerite.su
- drop zeitgeist Requires. check in minimal X it's no longer needed
- change colord to Recommends. without it cinnamon-settings-daemon
  will trigger a warning but won't prevent you from login
* Mon Nov 10 2014 i@marguerite.su
- update version 2.4.1
  * switched locale path to standard /usr/share/locale
  * re-add session timeout, disable by default
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
- drop patch: cinnamon-session-2.2.0-64bit-portability.patch
  * upstream fixed
* Tue Jul 15 2014 i@marguerite.su
- add nemo to requires
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * Remove 'remember open blah blah' in startup programs dialog
* Wed Jul  9 2014 stefan@fam-elser.de
- update version 2.2.2
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.1
* Thu Apr 17 2014 i@marguerite.su
- update version 2.2.0
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.6
  * Fixed wrong socket name for MDM
* Fri Nov  8 2013 johann.luce@wanadoo.fr
- update version 2.0.5
  * Remove upstart files (was breaking Unity)
* Sat Nov  2 2013 i@marguerite.su
- update version 2.0.4
  * fix screensaver command on inhibit dialog
* Fri Nov  1 2013 i@marguerite.su
- add cinnamon-screensaver to requirement
* Wed Oct 30 2013 i@marguerite.su
- add runtime requirement upstream didn't tell
  * NetworkManager-gnome, colord, zeitgeist
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.3
  * Add consolekit as runtime dep for debian package
  * depend on cinnamon-session-common
* Mon Oct 21 2013 i@marguerite.su
- copypac from home:cyberorg:cinnamon
- cleanup work
- add glib schemas macros
- remove --enable-systemd because by default it's auto and needs
  systemd >= 183, while openSUSE 12.2 only has 44
* Mon Oct 21 2013 stefan@fam-elser.de
- Added systemd as requirement
* Sun Oct 20 2013 stefan@fam-elser.de
- Updated spec file to enable systemd
* Thu Oct 10 2013 stefan@fam-elser.de
- Updated to version 2.0.1
* Wed Oct  9 2013 stefan@fam-elser.de
- Updated to version 2.0.0
* Wed Oct  2 2013 stefan@fam-elser.de
- Initial release with version 1.9.2
